//
//  UpnpAvContentDirectoryService.m
//  uPnp2
//
//  Created by rk on 10/03/11.
//  Copyright 2011 Interchart. All rights reserved.
//

#import "UpnpAvContentDirectoryService.h"
#import "OrderedDictionary.h"


@implementation UpnpAvContentDirectoryService

#pragma mark Designated Initializer
-(id)initWithService:(UpnpAvService *)theService {
	self = [super init];
	service = theService;
	return self;
}

#pragma mark AsynchUpnpCommandDelegate methods
- (void)handleAsynchUpnpCommandResult:(XMLTreeNode *)parsedResult {
	XMLTreeNode *resultNode = [parsedResult findChild: @"SOAP-ENV:Envelope/SOAP-ENV:Body/m:BrowseResponse/Result"];
	if (resultNode) {
		NSLog(@"%@: Result: %@", self, resultNode.text);
		// resultNode.text contains (escaped) XML to be parsed.
		NSData *data = [resultNode.text dataUsingEncoding:NSUTF8StringEncoding];
		XMLTreeParser *parser = [[XMLTreeParser alloc] init];
		XMLTreeNode *didlLiteNode = [parser parse:data];
		NSLog(@"%@: didlLiteNode:%@, didlLiteNode.text:%@, didlLiteNode.children.count:%d", 
			  self, 
			  didlLiteNode,
			  didlLiteNode.text,
			  didlLiteNode.children.count
			  );
		//NSArray *containers = [resultNode findChildren:@"container"];
		XMLTreeNode *containerNode = [didlLiteNode findChild:@"DIDL-Lite"];
		NSArray *containers = [containerNode.children valueForKey:@"container"];
		NSArray *items = [containerNode.children valueForKey:@"item"];
		NSLog(@"%@: resultNode.children: %@, containers.count:%d, items.count:%d", self, resultNode.children, containers.count, items.count);
		
		if ([getContainerContentDelegate respondsToSelector:@selector(getContainerContentHandler::)]) {
			[getContainerContentDelegate getContainerContentHandler:containers :items];
		}
	
	}
}

#pragma mark -

-(void)getContainerContent:(NSString *)containerId: (id)delegate {
	getContainerContentDelegate = delegate;
	[self doGetContainerContentCommand:containerId];
}


-(void)doGetContainerContentCommand:(NSString *)containerId {
	NSString *commandName = @"Browse";
	OrderedDictionary *args = [[OrderedDictionary alloc] init]; // Get 402 Upnp error if params are sent in wrong order...
	[args setValue:containerId forKey:@"ObjectID"];
	//[args setValue:@"BrowseMetadata" forKey:@"BrowseFlag"];
	[args setValue:@"BrowseDirectChildren" forKey:@"BrowseFlag"];
	[args setValue:@"*" forKey:@"Filter"];
	[args setValue:@"0" forKey:@"StartingIndex"];
	[args setValue:@"0" forKey:@"RequestedCount"];
	[args setValue:@"" forKey:@"SortCriteria"];
	
	AsynchUpnpCommand *command = [[AsynchUpnpCommand alloc] init];
	command.command = commandName;
	command.params = args;
	command.delegate = self;		
	
	[service executeCommandAsync:command];
}

@end
